#!python3
from threading import Thread
from eyes_soatra import eyes
import pandas
import json
import argparse

read_from = 'test/data/approved_data.csv'
records = pandas.read_csv(read_from).values
founds = []

def save_file(write_to):
    f = open(write_to, "w")
    
    try:
        json_data = json.dumps(founds, ensure_ascii=False, indent=4)
    except:
        json_data = None
        
    f.write(json_data if json_data else str(founds))
    f.close()
    
    print('\n--- done ---\n')
    print('length = ', len(founds))
    print('\n-------------\n')

def worker(start, end):
    for i in range(start, end):
        url = records[i][0]
        
        try:
            obj = eyes.view_page(url, show_header=True)
            
            if obj['active']:
                print(f'--- active {i} --- {url}')
                
            else:
                print(f'\n--- inactive {i} --- {url}\n')
                founds.append(obj)
            
                
        except:
            pass
        
def main(start_point, length, rows):
    length = (len(records) - start_point) if (start_point + length) > len(records) else length
    token = int(length / rows)
    write_to = f'test/checks/checked-{start_point}-{start_point + length} ({rows}).json'
    threads = []
    
    for i in range(0, rows):
        start = start_point + (i * token)
        
        if i == rows - 1:
            end = length
            thread = Thread(target=worker, kwargs={'start': start, 'end': end})
            threads.append(thread)
            
            for thread in threads:
                thread.start()
            
            for thread in threads:
                thread.join()
                
            save_file(write_to)

        else:
            end = start + token
            thread = Thread(target=worker, kwargs={'start': start, 'end': end})
            threads.append(thread)
        
if __name__ == '__main__':
    defaults = {
        'start': 0,
        'length': 1000,
        'row': 500
    }
    
    parser = argparse.ArgumentParser()
    parser.add_argument("-s", "--start", help="start point", default=defaults['start'])
    parser.add_argument("-l", "--length", help="length", default=defaults['length'])
    parser.add_argument("-r", "--row", help="row", default=defaults['row'])
    args = parser.parse_args()
    
    start_point = int(args.start)
    length = int(args.length)
    rows = int(args.row)

    main(start_point, length, rows)



#!python3
from eyes_soatra import eyes
import jellyfish
import urllib 
from urllib.request import urlopen
import requests
import pandas
import random

a = eyes.view_page(
    url='https://www.town.sakae.chiba.jp/page/page005484.html',
    # show_highlight=True,
    show_header=True,
)

print(a)

# __user_agents = [
#     'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36',
#     'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36',
#     'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36',
#     'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36',
#     'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36',
#     'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.1 Safari/605.1.15',
#     'Mozilla/5.0 (Macintosh; Intel Mac OS X 13_1) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.1 Safari/605.1.15',
# ]
# try:
#     a = requests.get(
#         url = 'http://www.nishiki-machi.com/docs/2022052700026/',
#         timeout=1
#     )
#     print(a)
    
# except Exception as ex:
#     print(f'{ex}')